@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 
-from enum import StrEnum
+try:
+    from enum import StrEnum
+
+except ImportError:
+    from core_https.utils import StrEnum
 
 
 class StatusInfo(StrEnum):
